@@ -16,9 +16,9 @@ class Model:
     joint: Joint angle
     model: A nested model state element
     scale: Scale for the 3 dimensions of the model.
-    frame: A frame of reference to which a pose is relative.
+    frame: A frame of reference in which poses may be expressed.
     pose: A position(x,y,z) and orientation(roll, pitch yaw) with
-        respect to the frame named in the relative_to attribute.
+        respect   to the frame named in the relative_to attribute.
     link: Link state
     name: Name of the model
     """
@@ -132,19 +132,33 @@ class Model:
     @dataclass
     class Frame:
         """
-        A frame of reference to which a pose is relative.
+        A frame of reference in which poses may be expressed.
 
         Parameters
         ----------
         pose: A position(x,y,z) and orientation(roll, pitch yaw) with
-            respect to the frame named in the relative_to attribute.
-        name: Name of the frame. This name must not match another frame
-            defined inside the parent that this frame is attached to.
-        attached_to: Name of the link or frame to which this frame is
-            attached.       If a frame is specified, recursively
-            following the attached_to attributes       of the specified
-            frames must lead to the name of a link, a model, or the
-            world frame.
+            respect   to the frame named in the relative_to attribute.
+        name: Name of the frame. It must be unique whithin its scope
+            (model/world),       i.e., it must not match the name of
+            another frame, link, joint, or model       within the same
+            scope.
+        attached_to: If specified, this frame is attached to the
+            specified frame. The specified       frame must be within
+            the same scope and may be defined implicitly, i.e.,
+            the name of any //frame, //model, //joint, or //link within
+            the same scope       may be used.        If missing, this
+            frame is attached to the containing scope's frame. Within
+            a //world scope this is the implicit world frame, and within
+            a //model       scope this is the implicit model frame.
+            A frame moves jointly with the frame it is @attached_to.
+            This is different       from //pose/@relative_to.
+            @attached_to defines how the frame is attached       to a
+            //link, //model, or //world frame, while //pose/@relative_to
+            defines       how the frame's pose is represented
+            numerically. As a result, following       the chain of
+            @attached_to attributes must always lead to a //link,
+            //model, //world, or //joint (implicitly attached_to its
+            child //link).
         """
 
         pose: Optional["Model.Frame.Pose"] = field(
@@ -175,8 +189,18 @@ class Model:
             Parameters
             ----------
             value:
-            relative_to: Name of frame relative to which the pose is
-                applied.
+            relative_to: If specified, this pose is expressed in the
+                named frame. The named frame       must be declared
+                within the same scope (world/model) as the element that
+                has its pose specified by this tag.        If missing,
+                the pose is expressed in the frame of the parent XML
+                element       of the element that contains the pose. For
+                exceptions to this rule and       more details on the
+                default behavior, see
+                http://sdformat.org/tutorials?tut=pose_frame_semantics.
+                Note that @relative_to merely affects an element's
+                initial pose and       does not affect the element's
+                dynamic movement thereafter.
             """
 
             value: str = field(
@@ -199,8 +223,17 @@ class Model:
         Parameters
         ----------
         value:
-        relative_to: Name of frame relative to which the pose is
-            applied.
+        relative_to: If specified, this pose is expressed in the named
+            frame. The named frame       must be declared within the
+            same scope (world/model) as the element that       has its
+            pose specified by this tag.        If missing, the pose is
+            expressed in the frame of the parent XML element       of
+            the element that contains the pose. For exceptions to this
+            rule and       more details on the default behavior, see
+            http://sdformat.org/tutorials?tut=pose_frame_semantics.
+            Note that @relative_to merely affects an element's initial
+            pose and       does not affect the element's dynamic
+            movement thereafter.
         """
 
         value: str = field(
@@ -238,7 +271,7 @@ class Model:
             correspond to the torque applied to the link
         collision: Collision state
         pose: A position(x,y,z) and orientation(roll, pitch yaw) with
-            respect to the frame named in the relative_to attribute.
+            respect   to the frame named in the relative_to attribute.
         name: Name of the link
         """
 
@@ -298,8 +331,18 @@ class Model:
             Parameters
             ----------
             value:
-            relative_to: Name of frame relative to which the pose is
-                applied.
+            relative_to: If specified, this pose is expressed in the
+                named frame. The named frame       must be declared
+                within the same scope (world/model) as the element that
+                has its pose specified by this tag.        If missing,
+                the pose is expressed in the frame of the parent XML
+                element       of the element that contains the pose. For
+                exceptions to this rule and       more details on the
+                default behavior, see
+                http://sdformat.org/tutorials?tut=pose_frame_semantics.
+                Note that @relative_to merely affects an element's
+                initial pose and       does not affect the element's
+                dynamic movement thereafter.
             """
 
             value: str = field(
@@ -465,7 +508,7 @@ class State:
         Parameters
         ----------
         pose: A position(x,y,z) and orientation(roll, pitch yaw) with
-            respect to the frame named in the relative_to attribute.
+            respect   to the frame named in the relative_to attribute.
         name: Name of the light
         """
 
@@ -491,8 +534,18 @@ class State:
             Parameters
             ----------
             value:
-            relative_to: Name of frame relative to which the pose is
-                applied.
+            relative_to: If specified, this pose is expressed in the
+                named frame. The named frame       must be declared
+                within the same scope (world/model) as the element that
+                has its pose specified by this tag.        If missing,
+                the pose is expressed in the frame of the parent XML
+                element       of the element that contains the pose. For
+                exceptions to this rule and       more details on the
+                default behavior, see
+                http://sdformat.org/tutorials?tut=pose_frame_semantics.
+                Note that @relative_to merely affects an element's
+                initial pose and       does not affect the element's
+                dynamic movement thereafter.
             """
 
             value: str = field(
